@@ -1,10 +1,10 @@
 package Net::DNS::RR::CSYNC;
 
 #
-# $Id: CSYNC.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: CSYNC.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -20,68 +20,69 @@ Net::DNS::RR::CSYNC - DNS CSYNC resource record
 use integer;
 
 use Net::DNS::Parameters;
+use Net::DNS::RR::NSEC;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
 	my $limit = $offset + $self->{rdlength};
-	@{$self}{qw(SOAserial flags)} = unpack "\@$offset Nn", $$data;
+	@{$self}{qw(soaserial flags)} = unpack "\@$offset Nn", $$data;
 	$offset += 6;
 	$self->{typebm} = substr $$data, $offset, $limit - $offset;
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless $self->{typebm};
-	pack 'N n a*', $self->SOAserial, $self->flags, $self->{typebm};
+	pack 'N n a*', $self->soaserial, $self->flags, $self->{typebm};
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{typebm};
-	my @rdata = $self->SOAserial, $self->flags, $self->typelist;
+	my @rdata = $self->soaserial, $self->flags, $self->typelist;
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
-	$self->SOAserial(shift);
+	$self->soaserial(shift);
 	$self->flags(shift);
 	$self->typelist(@_);
 }
 
 
-sub SOAserial {
+sub soaserial {
 	my $self = shift;
 
-	$self->{SOAserial} = 0 + shift if scalar @_;
-	return $self->{SOAserial} || 0;
+	$self->{soaserial} = 0 + shift if scalar @_;
+	$self->{soaserial} || 0;
 }
 
 
-sub soaserial {&SOAserial}
+sub SOAserial {&soaserial}
 
 
 sub flags {
 	my $self = shift;
 
 	$self->{flags} = 0 + shift if scalar @_;
-	return $self->{flags} || 0;
+	$self->{flags} || 0;
 }
 
 
 sub immediate {
 	my $bit = 0x0001;
-	for ( shift->{flags} ||= 0 ) {
-		return $_ & $bit unless scalar @_;
-		my $set = $_ | $bit;
+	for ( shift->{flags} ) {
+		my $set = $bit | ( $_ ||= 0 );
+		return $bit & $_ unless scalar @_;
 		$_ = (shift) ? $set : ( $set ^ $bit );
 		return $_ & $bit;
 	}
@@ -90,9 +91,9 @@ sub immediate {
 
 sub soaminimum {
 	my $bit = 0x0002;
-	for ( shift->{flags} ||= 0 ) {
-		return $_ & $bit unless scalar @_;
-		my $set = $_ | $bit;
+	for ( shift->{flags} ) {
+		my $set = $bit | ( $_ ||= 0 );
+		return $bit & $_ unless scalar @_;
 		$_ = (shift) ? $set : ( $set ^ $bit );
 		return $_ & $bit;
 	}
@@ -100,66 +101,7 @@ sub soaminimum {
 
 
 sub typelist {
-	my $self = shift;
-
-	$self->{typebm} = &_type2bm if scalar @_;
-
-	my @type = defined wantarray ? &_bm2type( $self->{typebm} ) : ();
-	return wantarray ? (@type) : "@type";
-}
-
-
-########################################
-
-sub _type2bm {
-	my @typearray;
-	foreach my $typename ( map split( /\s+/, $_ ), @_ ) {
-		next unless $typename;
-		my $number = typebyname($typename);
-		my $window = $number >> 8;
-		my $bitnum = $number & 255;
-		my $octet  = $bitnum >> 3;
-		my $bit	   = $bitnum & 7;
-		$typearray[$window][$octet] |= 0x80 >> $bit;
-	}
-
-	my @bitmap;
-	my $window = 0;
-	foreach (@typearray) {
-		if ( my $pane = $typearray[$window] ) {
-			my @content = map $_ || 0, @$pane;
-			push @bitmap, pack 'CC C*', $window, scalar(@content), @content;
-		}
-		$window++;
-	}
-
-	join '', @bitmap;
-}
-
-
-sub _bm2type {
-	my $bitmap = shift || '';
-	my $index  = 0;
-	my $limit  = length $bitmap;
-	my @typelist;
-
-	while ( $index < $limit ) {
-		my ( $block, $size ) = unpack "\@$index C2", $bitmap;
-		my $typenum = $block << 8;
-		foreach my $octet ( unpack "\@$index xxC$size", $bitmap ) {
-			my $i = $typenum += 8;
-			my @name;
-			while ($octet) {
-				--$i;
-				unshift @name, typebyval($i) if $octet & 1;
-				$octet = $octet >> 1;
-			}
-			push @typelist, @name;
-		}
-		$index += $size + 2;
-	}
-
-	return @typelist;
+	&Net::DNS::RR::NSEC::typelist;
 }
 
 
@@ -188,8 +130,11 @@ other unpredictable behaviour.
 
 =head2 SOAserial
 
-    $SOAserial = $rr->SOAserial;
-    $rr->SOAserial( $SOAserial );
+
+=head2 soaserial
+
+    $soaserial = $rr->soaserial;
+    $rr->soaserial( $soaserial );
 
 The SOA Serial field contains a copy of the 32-bit SOA serial number from
 the child zone.
