@@ -1,10 +1,10 @@
 package Net::DNS::RR::IPSECKEY;
 
 #
-# $Id: IPSECKEY.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: IPSECKEY.pm 1381 2015-08-25 07:36:09Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1381 $)[1];
 
 
 use strict;
@@ -20,11 +20,14 @@ Net::DNS::RR::IPSECKEY - DNS IPSECKEY resource record
 use integer;
 
 use Carp;
-use Net::DNS::DomainName;
 use MIME::Base64;
 
+use Net::DNS::DomainName;
+use Net::DNS::RR::A;
+use Net::DNS::RR::AAAA;
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -51,14 +54,14 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 		$self->{gateway} = $name;
 
 	} else {
-		croak "unknown gateway type ($gatetype)";
+		die "unknown gateway type ($gatetype)";
 	}
 
 	$self->keybin( substr $$data, $offset, $limit - $offset );
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless $self->{algorithm};
@@ -84,7 +87,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless $self->{algorithm};
@@ -94,11 +97,11 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->$_(shift) for qw(precedence gatetype algorithm gateway);
-	$self->key(@_) if scalar @_;
+	$self->key(@_);
 }
 
 
@@ -106,17 +109,12 @@ sub precedence {
 	my $self = shift;
 
 	$self->{precedence} = 0 + shift if scalar @_;
-	return $self->{precedence} || 0;
+	$self->{precedence} || 0;
 }
 
 
 sub gatetype {
-	my $self = shift;
-
-	$self->{gatespec} = shift if scalar @_;
-	my $gatetype = $self->{gatetype};
-	return $self->{gatespec} unless defined $gatetype;
-	return $gatetype;
+	return shift->{gatetype} || 0;
 }
 
 
@@ -124,50 +122,45 @@ sub algorithm {
 	my $self = shift;
 
 	$self->{algorithm} = 0 + shift if scalar @_;
-	return $self->{algorithm} || 0;
+	$self->{algorithm} || 0;
 }
 
 
 sub gateway {
 	my $self = shift;
 
-	my $gatetype = $self->gatetype;
-	if ( scalar @_ ) {
-		for ( shift || '.' ) {
-			( $_ eq '.' ) && do {
-				$gatetype = 0;
-				last;
-			};
-			/:.*:/ && do {
-				$gatetype = 2;
-				$self->{gateway} = pack 'n* @16', map hex($_), split /:/;
-				last;
-			};
-			/\.\d+$/ && do {
-				$gatetype = 1;
-				$self->{gateway} = pack 'C* @4', split /\./;
-				last;
-			};
-			/\..+/ && do {
-				$gatetype = 3;
-				$self->{gateway} = new Net::DNS::DomainName($_);
-				last;
-			};
-			croak "unrecognised gateway type";
-		}
-		my $declared = $self->{gatespec};
-		$declared = $gatetype unless defined $declared;
-		delete $self->{gatespec};
-		croak "gateway not type $declared" unless $gatetype == $declared;
-		$self->{gatetype} = $gatetype;
+	for (@_) {
+		/^\.*$/ && do {
+			$self->{gatetype} = 0;
+			$self->{gateway}  = undef;		# no gateway
+			last;
+		};
+		/:.*:/ && do {
+			$self->{gatetype} = 2;
+			$self->{gateway} = bless( {}, 'Net::DNS::RR::AAAA' )->address($_);
+			last;
+		};
+		/\.\d+$/ && do {
+			$self->{gatetype} = 1;
+			$self->{gateway} = bless( {}, 'Net::DNS::RR::A' )->address($_);
+			last;
+		};
+		/\..+/ && do {
+			$self->{gatetype} = 3;
+			$self->{gateway}  = new Net::DNS::DomainName($_);
+			last;
+		};
+		croak "unrecognised gateway type";
 	}
 
 	if ( defined wantarray ) {
-		return '.' if $gatetype == 0;
-		return join '.', unpack 'C4', $self->{gateway} if $gatetype == 1;
-		return sprintf '%x:%x:%x:%x:%x:%x:%x:%x', unpack 'n8', $self->{gateway} if $gatetype == 2;
+		my $gatetype = $self->{gatetype};
+		return wantarray ? '.' : undef unless $gatetype;
 		return $self->{gateway}->name if $gatetype == 3;
-		croak "unknown gateway type ($gatetype)";
+		my $gateway = {address => $self->{gateway}};
+		return bless( $gateway, 'Net::DNS::RR::A' )->address	if $gatetype == 1;
+		return bless( $gateway, 'Net::DNS::RR::AAAA' )->address if $gatetype == 2;
+		die "unknown gateway type ($gatetype)";
 	}
 }
 
@@ -176,7 +169,7 @@ sub key {
 	my $self = shift;
 
 	$self->keybin( MIME::Base64::decode( join "", @_ ) ) if scalar @_;
-	return MIME::Base64::encode( $self->keybin(), "" ) if defined wantarray;
+	MIME::Base64::encode( $self->keybin(), "" ) if defined wantarray;
 }
 
 
@@ -191,16 +184,13 @@ sub keybin {
 sub pubkey { &key; }
 
 
-# sort RRs in numerically ascending order.
-__PACKAGE__->set_rrsort_func(
-	'precedence',
-	sub {
-		my ( $a, $b ) = ( $Net::DNS::a, $Net::DNS::b );
-		$a->{precedence} <=> $b->{precedence};
-	} );
+my $function = sub {			## sort RRs in numerically ascending order.
+	$Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
+};
 
+__PACKAGE__->set_rrsort_func( 'preference', $function );
 
-__PACKAGE__->set_rrsort_func( 'default_sort', __PACKAGE__->get_rrsort_func('precedence') );
+__PACKAGE__->set_rrsort_func( 'default_sort', $function );
 
 
 1;
@@ -252,10 +242,14 @@ algorithm and determines the format of the public key field.
 =head2 gateway
 
     $gateway = $rr->gateway;
+    $rr->gateway( $gateway );
 
 The gateway field indicates a gateway to which an IPsec tunnel may be
 created in order to reach the entity named by this resource record.
 
+=head2 pubkey
+
+
 =head2 key
 
     $key = $rr->key;
@@ -275,7 +269,7 @@ Binary representation of the public key block for the resource record.
 
 Copyright (c)2007 Olaf Kolkman, NLnet Labs.
 
-Portions Copyright (c)2012 Dick Franks.
+Portions Copyright (c)2012,2015 Dick Franks.
 
 All rights reserved.
 
