@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC;
 
 #
-# $Id: NSEC.pm 1339 2015-04-16 13:01:17Z willem $
+# $Id: NSEC.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1339 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -23,7 +23,7 @@ use Net::DNS::DomainName;
 use Net::DNS::Parameters;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset ) = @_;
 
@@ -33,7 +33,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
 	return '' unless $self->{typebm};
@@ -41,7 +41,7 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my $nxtdname = $self->{nxtdname} || return '';
@@ -49,7 +49,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->nxtdname(shift);
@@ -79,8 +79,7 @@ sub typelist {
 
 sub _type2bm {
 	my @typearray;
-	foreach my $typename ( map split( /\s+/, $_ ), @_ ) {
-		next unless $typename;
+	foreach my $typename ( map split(), @_ ) {
 		my $number = typebyname($typename);
 		my $window = $number >> 8;
 		my $bitnum = $number & 255;
@@ -89,7 +88,7 @@ sub _type2bm {
 		$typearray[$window][$octet] |= 0x80 >> $bit;
 	}
 
-	my $bitmap;
+	my $bitmap = '';
 	my $window = 0;
 	foreach (@typearray) {
 		if ( my $pane = $typearray[$window] ) {
@@ -99,15 +98,16 @@ sub _type2bm {
 		$window++;
 	}
 
-	return $bitmap || '';
+	return $bitmap;
 }
 
 
 sub _bm2type {
-	my $bitmap = shift || '';
-	my $index  = 0;
-	my $limit  = length $bitmap;
 	my @typelist;
+	my $bitmap = shift || return @typelist;
+
+	my $index = 0;
+	my $limit = length $bitmap;
 
 	while ( $index < $limit ) {
 		my ( $block, $size ) = unpack "\@$index C2", $bitmap;
@@ -130,9 +130,9 @@ sub _bm2type {
 
 
 sub typebm {				## historical
-	my $self = shift;
-	return $self->{typebm} unless scalar @_;
-	$self->{typebm} = shift;
+	my $self = shift;					# uncoverable pod
+	$self->{typebm} = shift if scalar @_;
+	return $self->{typebm};
 }
 
 
