@@ -1,10 +1,10 @@
 package Net::DNS::RR::SOA;
 
 #
-# $Id: SOA.pm 1348 2015-05-27 09:55:13Z willem $
+# $Id: SOA.pm 1382 2015-08-26 20:39:33Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1348 $)[1];
+$VERSION = (qw$LastChangedRevision: 1382 $)[1];
 
 
 use strict;
@@ -23,7 +23,7 @@ use Net::DNS::DomainName;
 use Net::DNS::Mailbox;
 
 
-sub decode_rdata {			## decode rdata from wire-format octet string
+sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset, @opaque ) = @_;
 
@@ -33,7 +33,7 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 }
 
 
-sub encode_rdata {			## encode rdata as wire-format octet string
+sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 	my ( $offset, @opaque ) = @_;
 
@@ -44,14 +44,14 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 }
 
 
-sub format_rdata {			## format rdata portion of RR string.
+sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	return '' unless defined $self->{rname};
 	my $mname  = $self->{mname}->string;
 	my $rname  = $self->{rname}->string;
 	my $serial = $self->serial;
-	my $spacer = $serial > 9999999 ? "" : "\t";
+	my $spacer = length "$serial" > 7 ? "" : "\t";
 	my @rdata  = $mname, $rname, join "\n\t\t\t\t",
 			"\t\t\t$serial$spacer\t;serial",
 			"$self->{refresh}\t\t;refresh",
@@ -61,7 +61,7 @@ sub format_rdata {			## format rdata portion of RR string.
 }
 
 
-sub parse_rdata {			## populate RR from rdata in argument list
+sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->mname(shift);
@@ -73,10 +73,10 @@ sub parse_rdata {			## populate RR from rdata in argument list
 }
 
 
-sub defaults() {			## specify RR attribute default values
+sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
-	$self->parse_rdata(qw(. . 0 4h 1h 3w 1h));
+	$self->_parse_rdata(qw(. . 0 4h 1h 3w 1h));
 	$self->{serial} = undef;
 }
 
@@ -116,7 +116,7 @@ sub refresh {
 	my $self = shift;
 
 	$self->{refresh} = 0 + shift if scalar @_;
-	return $self->{refresh} || 0;
+	$self->{refresh} || 0;
 }
 
 
@@ -124,7 +124,7 @@ sub retry {
 	my $self = shift;
 
 	$self->{retry} = 0 + shift if scalar @_;
-	return $self->{retry} || 0;
+	$self->{retry} || 0;
 }
 
 
@@ -132,7 +132,7 @@ sub expire {
 	my $self = shift;
 
 	$self->{expire} = 0 + shift if scalar @_;
-	return $self->{expire} || 0;
+	$self->{expire} || 0;
 }
 
 
@@ -140,7 +140,7 @@ sub minimum {
 	my $self = shift;
 
 	$self->{minimum} = 0 + shift if scalar @_;
-	return $self->{minimum} || 0;
+	$self->{minimum} || 0;
 }
 
 
