@@ -1,10 +1,10 @@
 package Net::DNS::Update;
 
 #
-# $Id: Update.pm 1359 2015-06-11 17:21:03Z willem $
+# $Id: Update.pm 1381 2015-08-25 07:36:09Z willem $
 #
 use vars qw($VERSION @ISA);
-$VERSION = (qw$LastChangedRevision: 1359 $)[1];
+$VERSION = (qw$LastChangedRevision: 1381 $)[1];
 
 
 =head1 NAME
@@ -82,6 +82,69 @@ sub new {
 }
 
 
+=head2 push
+
+    $ancount = $update->push( prereq => $rr );
+    $nscount = $update->push( update => $rr );
+    $arcount = $update->push( additional => $rr );
+
+    $nscount = $update->push( update => $rr1, $rr2, $rr3 );
+    $nscount = $update->push( update => @rr );
+
+Adds RRs to the specified section of the update packet.
+
+Returns the number of resource records in the specified section.
+
+Section names may be abbreviated to the first three characters.
+
+=cut
+
+sub push {
+	my $self = shift;
+	my $list = $self->_section(shift);
+	my @arg	 = grep ref($_), @_;
+
+	my ($zone) = $self->zone;
+	my $zclass = $zone->zclass;
+	my @rr = grep $_->class( $_->class =~ /ANY|NONE/ ? () : $zclass ), @arg;
+
+	CORE::push( @$list, @rr );
+}
+
+
+=head2 unique_push
+
+    $ancount = $update->unique_push( prereq => $rr );
+    $nscount = $update->unique_push( update => $rr );
+    $arcount = $update->unique_push( additional => $rr );
+
+    $nscount = $update->unique_push( update => $rr1, $rr2, $rr3 );
+    $nscount = $update->unique_push( update => @rr );
+
+Adds RRs to the specified section of the update packet provided
+that the RRs are not already present in the same section.
+
+Returns the number of resource records in the specified section.
+
+Section names may be abbreviated to the first three characters.
+
+=cut
+
+sub unique_push {
+	my $self = shift;
+	my $list = $self->_section(shift);
+	my @arg	 = grep ref($_), @_;
+
+	my ($zone) = $self->zone;
+	my $zclass = $zone->zclass;
+	my @rr = grep $_->class( $_->class =~ /ANY|NONE/ ? () : $zclass ), @arg;
+
+	my %unique = map { ( bless( {%$_, ttl => 0}, ref $_ )->canonical => $_ ) } @rr, @$list;
+
+	scalar( @$list = values %unique );
+}
+
+
 1;
 
 __END__
@@ -89,8 +152,11 @@ __END__
 
 =head1 EXAMPLES
 
-The first example below shows a complete program;
-subsequent examples show only the creation of the update packet .
+The first example below shows a complete program.
+Subsequent examples show only the creation of the update packet.
+
+Although the examples are presented using the string form of RRs,
+the corresponding ( name => value ) form may also be used.
 
 =head2 Add a new host
 
@@ -132,7 +198,7 @@ subsequent examples show only the creation of the update packet .
     $update->push( prereq => yxdomain('example.com') );
     $update->push( update => rr_add('example.com MX 10 mailhost.example.com') );
 
-=head2 Add a TXT record for a name that doesn't exist
+=head2 Add a TXT record for a name that does not exist
 
     my $update = new Net::DNS::Update('example.com');
     $update->push( prereq => nxdomain('info.example.com') );
@@ -165,8 +231,8 @@ subsequent examples show only the creation of the update packet .
 =head2 Signing the DNS update using a customised TSIG record
 
     $update->sign_tsig( "$dir/Khmac-sha512.example.com.+165+01018.private",
-                        fudge => 60
-                        );
+			fudge => 60
+			);
 
 =head2 Another way to sign a DNS update
 
@@ -187,6 +253,8 @@ Copyright (c)1997-2000 Michael Fuhr.
 
 Portions Copyright (c)2002,2003 Chris Reinhardt.
 
+Portions Copyright (c)2015 Dick Franks.
+
 All rights reserved.
 
 
